/*****************************************
 *      nRF24L01P module
 *
 *
 *
 * **************************************/
 
#include "nRF24L01P_SPI.h"
#include "main.h" 

void SPI_init(void)
{
 SPI_TRIS = (1<<CE_PIN) | (1<<SCK_PIN) | (1<<CSN_PIN) | (1<<MOSI_PIN) | (1<<MISO_PIN);
 sbi(CSN_PIN);
}

/**********************************************************************
* Function:        unsigned char SPI_r_w_byte(unsigned char spi_r_byte)
* PreCondition:    void SPI_init(void)
* Input:        byte from write line .
* Output:		   Return the byte at line.
***********************************************************************/
unsigned char SPI_r_w_byte(unsigned char spi_r_byte)
{  unsigned char SPI_counter;
 //   
 for(SPI_counter = 8; SPI_counter != 0; SPI_counter--)
 {
 //      - 1
 if (spi_r_byte & MSBit)
 //    MOSI  
 sbi(MOSI_PIN);
 //    -
 else
 //
 cbi(MOSI_PIN);
 //      
 //   byte,   
 spi_r_byte <<= 1;
 //     SCK-
 sbi(SCK_PIN);
 //      - 1
 if ((HIGH_PIN & MISO_PIN))
 //     byte  1
 spi_r_byte |= LSBit;
 //       0,   , ..
 //    byte      0
 //  SCK-
 cbi(SCK_PIN);
 }
 //        
 return spi_r_byte;
}



/**********************************************************************
* Function:     void nRF_sendcommand(unsigned char command)
* Input:     byte command for nRF
* Output:     None
***********************************************************************/

void nRF_sendcommand(unsigned char command)
{
 cbi(CSN_PIN);
 SPI_r_w_byte(command);
 sbi(CSN_PIN);
}

/**********************************************************************
* Function:  void nRF_Wregister(unsigned char reg, unsigned char data_out)
* Input:     byte register for nRF and write byte data
* Output:     None
***********************************************************************/

void nRF_Wregister(unsigned char reg, unsigned char data_out)
{
 reg |= W_REGISTER;
 cbi(CSN_PIN);
 SPI_r_w_byte(reg);
 SPI_r_w_byte(data_out);
 sbi(CSN_PIN);
}

/**********************************************************************
* Function:  unsigned char nRF_Rregister(unsigned char reg)
* Input:    adresse byte at register  nRF
* Output:    return read byte as register  nRF
***********************************************************************/

unsigned char nRF_Rregister(unsigned char reg)
{
 unsigned char data_in;
 cbi(CSN_PIN);
 data_in = SPI_r_w_byte(reg);
 if(reg != STATUS)
 {
 data_in = SPI_r_w_byte(NOPS);
 }
 sbi(CSN_PIN);
 return data_in;
}
